/*
 * tsys02d.h
 *
 *  Created on: Jul 30, 2014
 *      Author: JMBrinkhus
 */

#include <stdio.h>
#include "xiic_l.h"


#ifndef TSYS02D_H_
#define TSYS02D_H_

// TSYS02D Constants
#define TSYS02D_I2C_ADDR			(0x40)	// 1000_000x
#define TSYS02D_CONV_DELAY_MS		(45)	// Datasheet says 43ms, 45ms to be safe
#define CRC_POLY					(0x131)	// CRC Polynomial: X^8 + X^5 + X^4 + 1

// TSYS02D I2C Commands
#define TSYS02D_I2C_CMD_RESET					(0xFE)
#define TSYS02D_I2C_CMD_READ_PROM_FIRST8		(0xFA0F)
#define TSYS02D_I2C_CMD_READ_PROM_LAST6			(0xFCC9)
#define TSYS02D_I2C_CMD_START_ADC				(0xF3)		//Without hold
#define TSYS02D_I2C_CMD_READ_ADC				(0x00)

typedef enum tsys02d_status{
	tsys02d_status_ok = 0,
	tsys02d_status_i2c_transfer_error = 1,
	tsys02d_status_crc_error = 2
}tsys02d_status;

#endif /* TSYS02D_H_ */

// External variables
extern 	u32 			tsys02d_axi_address;
extern 	u8	 			tsys02d_serial_number[8];

// Function Declarations
void tsys02d_init(u32 axi_address);
tsys02d_status tsys02d_reset(void);
tsys02d_status tsys02d_read_serial_number(void);
tsys02d_status tsys02d_read_temperature(float* temperature);
int CRC8(char*);
int CRC16(char*);
